@@ -80,6 +80,13 @@ DataImpl :: add_new_server ()
   return new_server;
 }
 
+quarks_t DataImpl ::get_servers () const {
+  quarks_t servers;
+  foreach_const (servers_t, _servers, it)
+    servers.insert (it->first);
+  return servers;
+}
+
 Data ::Server *DataImpl ::find_server(Quark const &server)
 {
   Server * retval (nullptr);
@@ -551,10 +558,10 @@ DataImpl :: save_server_properties (DataIO& data_io, Prefs& prefs)
          << indent(depth) << "<port>" << s->port << "</port>\n"
          << indent(depth) << "<username>" << escaped(user) << "</username>\n";
 #ifdef HAVE_GKR
-if (prefs.get_flag("use-password-storage", USE_LIBSECRET_DEFAULT))
-    *out << indent(depth) << "<password>" << "HANDLED_BY_PASSWORD_STORAGE" << "</password>\n";
-else
-    *out << indent(depth) << "<password>" << escaped(pass) << "</password>\n";
+    if (prefs.get_flag("use-password-storage", USE_LIBSECRET_DEFAULT))
+      *out << indent(depth) << "<password>" << "HANDLED_BY_PASSWORD_STORAGE" << "</password>\n";
+    else
+      *out << indent(depth) << "<password>" << escaped(pass) << "</password>\n";
 #else
     *out << indent(depth) << "<password>" << escaped(pass) << "</password>\n";
 #endif
