@@ -22,13 +22,13 @@
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include "gtk-compat.h"
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <pan/general/macros.h>
 #include <pan/tasks/queue.h>
 #include <pan/tasks/task-xover.h>
 #include "pad.h"
 
-#include <pan/general/null.h>
 
 namespace pan {
 
@@ -132,7 +132,7 @@ void headers_dialog (Data& data, Prefs& prefs, Queue& queue,
       title.c_str(), parent, GTK_DIALOG_DESTROY_WITH_PARENT,
       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
       GTK_STOCK_EXECUTE, GTK_RESPONSE_ACCEPT,
-      NULL);
+      nullptr);
     gtk_dialog_set_default_response (GTK_DIALOG(state->dialog), GTK_RESPONSE_ACCEPT);
 
     GtkWidget * t = gtk_table_new (4, 2, FALSE); // rows, cols, homogenous
@@ -145,7 +145,7 @@ void headers_dialog (Data& data, Prefs& prefs, Queue& queue,
     GtkWidget *w, *x;
     GtkAdjustment * adj;
     int row = 0;
-    state->n_days_rb = w = gtk_radio_button_new_with_mnemonic (NULL, _("Get the last N _days' headers: "));
+    state->n_days_rb = w = gtk_radio_button_new_with_mnemonic (nullptr, _("Get the last N _days' headers: "));
     gtk_button_set_alignment (GTK_BUTTON(w), 0.5, 0.0);
     gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+1);
     adj = GTK_ADJUSTMENT(gtk_adjustment_new (n_days, 1, INT_MAX, 1, 1, 0));
