@@ -2785,19 +2785,19 @@ void HeaderPane ::read_next_unread_article()
   read_next_if(ArticleIsUnread(_data));
 }
 
-void HeaderPane ::read_previous_article()
-{
-  read_prev_if(ArticleExists());
+void HeaderPane ::read_previous_article() {
+  if (_atree && _atree->size() > 0)
+    read_prev_if(ArticleExists());
 }
 
-void HeaderPane ::read_next_article()
-{
-  read_next_if(ArticleExists());
+void HeaderPane ::read_next_article() {
+  if (_atree && _atree->size() > 0)
+    read_next_if(ArticleExists());
 }
 
 void HeaderPane ::read_next_thread()
 {
-  if (_atree)
+  if (_atree && _atree->size() > 0)
   {
     read_next_if(ArticleIsNotInThread(*_atree, get_first_selected_article()));
   }
@@ -2805,7 +2805,7 @@ void HeaderPane ::read_next_thread()
 
 void HeaderPane ::read_next_unread_thread()
 {
-  if (_atree)
+  if (_atree && _atree->size() > 0)
   {
     read_next_if(ArticleIsUnreadAndNotInThread(
       _data, *_atree, get_first_selected_article()));
@@ -2814,7 +2814,7 @@ void HeaderPane ::read_next_unread_thread()
 
 void HeaderPane ::read_previous_thread()
 {
-  if (_atree)
+  if (_atree && _atree->size() > 0)
   {
     read_prev_if(ArticleIsNotInThread(*_atree, get_first_selected_article()));
   }
@@ -2822,7 +2822,7 @@ void HeaderPane ::read_previous_thread()
 
 void HeaderPane ::read_parent_article()
 {
-  if (_atree)
+  if (_atree && _atree->size() > 0)
   {
     read_prev_if(ArticleIsParentOf(*_atree, get_first_selected_article()));
   }
