@@ -93,20 +93,20 @@ TaskUpload :: TaskUpload (const std::string         & filename,
                           GMimeMessage *              msg,
                           Progress::Listener        * listener):
   Task ("UPLOAD", get_description(filename.c_str())),
+  _server(server),
+  _encoder(nullptr),
+  _encoder_has_run (false),
   _filename(filename),
   _basename (g_get_basename(filename.c_str())),
-  _server(server),
-  _cache(cache),
-  _article(article),
   _subject (article.subject.to_string()),
   _author(article.author.to_string()),
-  _encoder(0),
-  _encoder_has_run (false),
-  _all_bytes(0),
-  _bpf(format.bpf),
-  _total_parts(format.total),
   _save_file(format.save_file),
+  _total_parts(format.total),
+  _cache(cache),
+  _article(article),
+  _all_bytes(0),
   _queue_pos(0),
+  _bpf(format.bpf),
   _msg (msg),
   _first(true),
   _groups(get_groups_str(article))
@@ -226,10 +226,10 @@ void
 TaskUpload :: use_nntp (NNTP * nntp)
 {
 
-  Needed * needed (0);
+  Needed * needed (nullptr);
   foreach (needed_t, _needed, nit)
   {
-      if (nit->second.nntp==0)
+      if (nit->second.nntp==nullptr)
       {
         needed = &nit->second;
         break;
@@ -304,12 +304,13 @@ TaskUpload :: on_nntp_done (NNTP * nntp,
 
   switch (atoi(response.str))
   {
-    case NO_POSTING:
+    case NNTP::NO_POSTING:
       Log :: add_err_va (_("Posting of file %s (part %d of %d) failed: No posts allowed by server."),
                  _basename.c_str(), it->second.partno,  _total_parts);
       this->stop();
       break;
-    case POSTING_FAILED:
+
+    case NNTP::POSTING_FAILED:
       if (health != OK)     // if we got a dupe, the health is OK, so skip that
       {
         tmp.severity = Log :: PAN_SEVERITY_ERROR;
@@ -319,7 +320,8 @@ TaskUpload :: on_nntp_done (NNTP * nntp,
         _logfile.push_front(tmp);
       }
       break;
-    case ARTICLE_POSTED_OK:
+
+    case NNTP::ARTICLE_POSTED_OK:
       tmp.severity = Log :: PAN_SEVERITY_INFO;
       if (post_ok && !_needed.empty())
       {
@@ -353,10 +355,12 @@ TaskUpload :: on_nntp_done (NNTP * nntp,
         _logfile.clear();
       }
       break;
-    case TOO_MANY_CONNECTIONS:
+
+    case NNTP::TOO_MANY_CONNECTIONS:
       // lockout for 120 secs, but try
       it->second.reset();
       break;
+
     default:
       _needed.erase (it);
       Log::add_entry_list (tmp, _logfile);
@@ -400,7 +404,7 @@ TaskUpload :: use_encoder (Encoder* encoder)
   _state.set_working();
 
   _encoder->enqueue (this, &_cache, &_article, _filename, _basename, _master_subject, _bpf);
-  debug ("encoder thread was free, enqueued work");
+  pan_debug ("encoder thread was free, enqueued work");
 }
 
 void
@@ -445,7 +449,7 @@ TaskUpload :: on_worker_done (bool cancelled)
   }
 
   Encoder * d (_encoder);
-  _encoder = 0;
+  _encoder = nullptr;
   update_work ();
   check_in (d);
 
